@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -26,6 +26,6 @@ public:
 
 private:
     void slotConfigChanged();
-    PimCommon::ConfigurePluginsWidget *mConfigurePluginWidget = nullptr;
+    PimCommon::ConfigurePluginsWidget *const mConfigurePluginWidget;
 };
 }
