@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -26,6 +26,6 @@ public:
     void defaults() override;
 
 private:
-    KUserFeedback::FeedbackConfigWidget *mUserFeedbackWidget = nullptr;
+    KUserFeedback::FeedbackConfigWidget *const mUserFeedbackWidget;
 };
 }
