@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -32,9 +32,7 @@ KAddressBookConfigPluginListWidget::KAddressBookConfigPluginListWidget(QWidget *
     connect(this, &KAddressBookConfigPluginListWidget::configureClicked, this, &KAddressBookConfigPluginListWidget::slotConfigureClicked);
 }
 
-KAddressBookConfigPluginListWidget::~KAddressBookConfigPluginListWidget()
-{
-}
+KAddressBookConfigPluginListWidget::~KAddressBookConfigPluginListWidget() = default;
 
 void KAddressBookConfigPluginListWidget::save()
 {
