@@ -1,10 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-
 #include "kaddressbookmigrateapplication.h"
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 
 #include <Kdelibs4ConfigMigrator>
 
@@ -64,3 +64,4 @@ void KAddressBookMigrateApplication::initializeMigrator()
 
     // TODO add folder to migrate
 }
+#endif
