@@ -1,12 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #pragma once
-
 #include "kaddressbook_export.h"
+#include <QObject>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <PimCommon/MigrateApplicationFiles>
 
 class KADDRESSBOOK_EXPORT KAddressBookMigrateApplication
@@ -19,4 +20,4 @@ private:
     void initializeMigrator();
     PimCommon::MigrateApplicationFiles mMigrator;
 };
-
+#endif
