@@ -45,7 +45,9 @@
 #include <Akonadi/EntityMimeTypeFilterModel>
 #include <Akonadi/EntityTreeView>
 #include <Akonadi/MimeTypeChecker>
+#ifndef FORCE_DISABLE_AKONADI_SEARCH
 #include <Debug/akonadisearchdebugdialog.h>
+#endif
 #include <KContacts/Addressee>
 #include <PimCommon/PimUtil>
 #include <PimCommonAkonadi/ManageServerSideSubscriptionJob>
@@ -76,7 +78,8 @@
 #include <QTextBrowser>
 
 #include <Akonadi/ItemModifyJob>
-#include <PimCommon/KPimPrintPreviewDialog>
+#include <KColorSchemeManager>
+#include <KWindowStateSaver>
 #include <QActionGroup>
 #include <QDBusConnection>
 #include <QHBoxLayout>
@@ -302,6 +305,25 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
     initializeImportExportPlugin(guiClient->actionCollection());
     QMetaObject::invokeMethod(this, &MainWidget::delayedInit, Qt::QueuedConnection);
     updateQuickSearchText();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    connect(qApp, &QApplication::paletteChanged, this, &MainWidget::slotGeneralPaletteChanged);
+#endif
+}
+
+void MainWidget::slotGeneralPaletteChanged()
+{
+    mContactDetails->updateView();
+    mContactGroupDetails->updateView();
+}
+
+bool MainWidget::event(QEvent *e)
+{
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    if (e->type() == QEvent::ApplicationPaletteChange) {
+        slotGeneralPaletteChanged();
+    }
+#endif
+    return QWidget::event(e);
 }
 
 void MainWidget::setFocusToTreeView()
@@ -346,7 +368,8 @@ void MainWidget::initializeImportExportPlugin(KActionCollection *collection)
 void MainWidget::configure()
 {
     QPointer<KCMultiDialog> dlg = new KCMultiDialog(this);
-    const QVector<KPluginMetaData> availablePlugins = KPluginMetaData::findPlugins(QStringLiteral("pim/kcms/kaddressbook"));
+    const QVector<KPluginMetaData> availablePlugins =
+        KPluginMetaData::findPlugins(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/kcms/kaddressbook"));
     for (const KPluginMetaData &metaData : availablePlugins) {
         dlg->addModule(metaData);
     }
@@ -673,17 +696,20 @@ void MainWidget::setupActions(KActionCollection *collection)
     collection->addAction(QStringLiteral("focus_to_quickseach"), mQuickSearchAction);
     connect(mQuickSearchAction, &QAction::triggered, mQuickSearchWidget, &QuickSearchWidget::slotFocusQuickSearch);
     collection->setDefaultShortcut(mQuickSearchAction, QKeySequence(Qt::ALT | Qt::Key_Q));
-
+#ifndef FORCE_DISABLE_AKONADI_SEARCH
     if (!qEnvironmentVariableIsEmpty("KDEPIM_DEBUGGING")) {
         action = collection->addAction(QStringLiteral("debug_akonadi_search"));
         // Don't translate it. It's just for debug
         action->setText(QStringLiteral("Debug Akonadi Search..."));
         connect(action, &QAction::triggered, this, &MainWidget::slotDebugAkonadiSearch);
     }
-
+#endif
     mServerSideSubscription = new QAction(QIcon::fromTheme(QStringLiteral("folder-bookmarks")), i18n("Serverside Subscription..."), this);
     collection->addAction(QStringLiteral("serverside_subscription"), mServerSideSubscription);
     connect(mServerSideSubscription, &QAction::triggered, this, &MainWidget::slotServerSideSubscription);
+
+    auto manager = new KColorSchemeManager(this);
+    collection->addAction(QStringLiteral("colorscheme_menu"), manager->createSchemeSelectionMenu(this));
 }
 
 void MainWidget::printPreview()
@@ -694,7 +720,9 @@ void MainWidget::printPreview()
     printer.setOutputFormat(QPrinter::PdfFormat);
     printer.setCollateCopies(true);
 
-    QPointer<PimCommon::KPimPrintPreviewDialog> previewdlg = new PimCommon::KPimPrintPreviewDialog(&printer, this);
+    QPointer<QPrintPreviewDialog> previewdlg = new QPrintPreviewDialog(&printer, this);
+    new KWindowStateSaver(previewdlg.data(), "KAddressBookPrintPreviewDialog");
+
     KABPrinting::PrintingWizard wizard(&printer, mItemView->selectionModel(), this);
     wizard.setDefaultAddressBook(currentAddressBook());
     connect(previewdlg.data(), &QPrintPreviewDialog::paintRequested, this, [&wizard]() {
@@ -801,18 +829,20 @@ void MainWidget::setQRCodeShow(bool on)
     }
 }
 
-Akonadi::Item::List MainWidget::selectedItems()
+Akonadi::Item::List MainWidget::selectedItems(bool &canceled)
 {
     Akonadi::Item::List items;
     QPointer<KAddressBookImportExport::ContactSelectionDialog> dlg =
         new KAddressBookImportExport::ContactSelectionDialog(mItemView->selectionModel(), false, this);
     dlg->setDefaultAddressBook(currentAddressBook());
     if (!dlg->exec() || !dlg) {
+        canceled = true;
         delete dlg;
         return items;
     }
 
     items = dlg->selectedItems();
+    canceled = false;
     delete dlg;
 
     return items;
@@ -990,6 +1020,7 @@ const Akonadi::Item::List MainWidget::collectSelectedAllContactsItem()
 
 void MainWidget::slotDebugAkonadiSearch()
 {
+#ifndef FORCE_DISABLE_AKONADI_SEARCH
     const Akonadi::Item::List lst = collectSelectedAllContactsItem(mItemView->selectionModel());
     if (lst.isEmpty()) {
         return;
@@ -1000,6 +1031,7 @@ void MainWidget::slotDebugAkonadiSearch()
     dlg->setSearchType(Akonadi::Search::AkonadiSearchDebugSearchPathComboBox::Contacts);
     dlg->doSearch();
     dlg->show();
+#endif
 }
 
 const Akonadi::Item::List MainWidget::collectSelectedAllContactsItem(QItemSelectionModel *model)
