@@ -17,8 +17,10 @@
 #include <KSharedConfig>
 #include <KShortcutsDialog>
 #include <KStandardAction>
+#include <KToggleFullScreenAction>
 #include <KToolBar>
 #include <QAction>
+#include <QFontDatabase>
 #include <QMenuBar>
 #include <QPointer>
 #ifdef WITH_KUSERFEEDBACK
@@ -31,10 +33,8 @@ MainWindow::MainWindow()
     : KXmlGuiWindow(nullptr)
     , mMainWidget(new MainWidget(this, this))
 {
-
     setCentralWidget(mMainWidget);
 
-
     setStandardToolBarMenuEnabled(true);
 
     toolBar()->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
@@ -82,6 +82,29 @@ void MainWindow::initActions()
             disconnect(mHamburgerMenu, &KHamburgerMenu::aboutToShowMenu, this, nullptr);
         });
     }
+    mShowFullScreenAction = KStandardAction::fullScreen(nullptr, nullptr, this, actionCollection());
+    actionCollection()->setDefaultShortcut(mShowFullScreenAction, Qt::Key_F11);
+    connect(mShowFullScreenAction, &QAction::toggled, this, &MainWindow::slotFullScreen);
+}
+
+void MainWindow::slotFullScreen(bool t)
+{
+    KToggleFullScreenAction::setFullScreen(this, t);
+    QMenuBar *mb = menuBar();
+    if (t) {
+        auto b = new QToolButton(mb);
+        b->setDefaultAction(mShowFullScreenAction);
+        b->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Ignored));
+        b->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
+        mb->setCornerWidget(b, Qt::TopRightCorner);
+        b->setVisible(true);
+        b->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+    } else {
+        QWidget *w = mb->cornerWidget(Qt::TopRightCorner);
+        if (w) {
+            w->deleteLater();
+        }
+    }
 }
 
 void MainWindow::updateHamburgerMenu()
