@@ -23,7 +23,7 @@ public:
 
     void setMainWidget(MainWidget *mainWidget);
 
-    void initializeInterfaceRequires(PimCommon::AbstractGenericPluginInterface *interface) override;
+    bool initializeInterfaceRequires(PimCommon::AbstractGenericPluginInterface *interface) override;
     static KAddressBookPluginInterface *self();
 
 private:
